==> wls-plugin-3.5.0-sources.jar: wls/jms/create-udd-queue.py <==

clusterOrJmsServer = deployed.container
if hasattr(clusterOrJmsServer, 'server'):
    #target is a jmsServer, so get the server from it
    clusterOrJmsServer = clusterOrJmsServer.server

connectAndEdit()
createOrUpdateJmsModuleWithTarget(deployed.jmsModuleName, clusterOrJmsServer.objectName)
createOrUpdateSubDeploymentWithTarget(deployed.jmsModuleName, deployed.subDeploymentName, deployed.container.objectName)

queuePath = '/JMSSystemResources/%s/JMSResource/%s/UniformDistributedQueues/%s' % (deployed.jmsModuleName, deployed.jmsModuleName, deployed.name)

if exists(queuePath):
    print 'Modifying UDD queue %s for target %s' % (deployed.name, deployed.container.name)
    setOrOverride = overrideWithWarning
else:
    print 'Creating UDD queue %s for target %s' % (deployed.name, deployed.container.name)
    cd('/JMSSystemResources/'+deployed.jmsModuleName+'/JMSResource/'+deployed.jmsModuleName)
    cmo.createUniformDistributedQueue(deployed.name)
    setOrOverride = set

cd(queuePath)
setOrOverride("JNDIName", deployed.jndiName)
setOrOverride("SubDeploymentName", deployed.subDeploymentName)

#set extra values in any at this level
propsToSet = deployed.getExposedProperties()
print 'propsToSet: %s' %(propsToSet)
for key, value in propsToSet.items():
    if value is not None and isinstance(value, DictionaryObject) == False:
        print 'setting %s with value %s' % (key, value)
        setOrOverride(key, value)

# create all the nested objects like DeliveryFailureParams, DeliveryParamsOverrides etc..
nestedObjects = findAllNestedObjects(deployed)
if len(nestedObjects) != 0:
    print "now setting properties %s" %(nestedObjects)
    setNestedPropertiesRecursively(deployed.name, queuePath, nestedObjects, set)

saveAndExit()

==> wls-plugin-5.5.0-sources.jar: wls/jms/create-udd-queue.py <==
connectAndEdit()
createOrUpdateJmsModuleWithTarget(deployed.jmsModuleName, toWlsContainer(deployed.container).objectName)
createOrUpdateSubDeploymentWithTarget(deployed.jmsModuleName, deployed.subDeploymentName, deployed.container.objectName)

queuePath = '/JMSSystemResources/%s/JMSResource/%s/UniformDistributedQueues/%s' % (deployed.jmsModuleName, deployed.jmsModuleName, deployed.name)

if exists(queuePath):
    print 'Modifying UDD queue %s for target %s' % (deployed.name, deployed.container.name)
    setOrOverride = overrideWithWarning
else:
    print 'Creating UDD queue %s for target %s' % (deployed.name, deployed.container.name)
    cd('/JMSSystemResources/'+deployed.jmsModuleName+'/JMSResource/'+deployed.jmsModuleName)
    cmo.createUniformDistributedQueue(deployed.name)
    setOrOverride = set

cd(queuePath)
setOrOverride("JNDIName", deployed.jndiName)
setOrOverride("SubDeploymentName", deployed.subDeploymentName)

#set extra values in any at this level
propsToSet = deployed.getExposedProperties()
print 'propsToSet: %s' %(propsToSet)
for key, value in propsToSet.items():
    if value is not None and isinstance(value, DictionaryObject) == False:
        print 'setting %s with value %s' % (key, value)
        setOrOverride(key, value)

# create all the nested objects like DeliveryFailureParams, DeliveryParamsOverrides etc..
nestedObjects = findAllNestedObjects(deployed)
if len(nestedObjects) != 0:
    print "now setting properties %s" %(nestedObjects)
    setNestedPropertiesRecursively(deployed.name, queuePath, nestedObjects, set)

saveAndExit()
